@@ -815,6 +815,13 @@ async fn test_java_maven() {
     assert!(output.contains("Built with Spring Boot"));
 }
 
+#[tokio::test]
+async fn test_php_vanilla() {
+    let name = simple_build("./examples/php-vanilla").await;
+    let output = run_image(&name, None).await;
+    assert!(output.contains("Server starting on port 80"));
+}
+
 #[tokio::test]
 async fn test_scala_sbt() {
     let name = simple_build("./examples/scala-sbt").await;
